def load_ss(filename):
    """Prende in ingresso un file in formato UNIPROT.
Restituisce una lista di coppie (elemento di struttura secondaria, lunghezza)."""
    f = open(filename)
    l = []

    for row in f:
        if row.startswith("FT"):
            if "STRAND" in row or "TURN" in row or "HELIX" in row:
                data = row.split()
                ss_type = data[1]
                ss_lenght = int(data[3])-int(data[2])+1
                l.append((ss_type,ss_lenght))
    f.close()
    return l

def sum_value_to_diz(diz, k, v):
    """Prende in ingresso un dizionario, una chiave ed un valore.
Aggiorna il dizionario sommando al valore della chiave il nuovo 
valore se presente, o creando la coppia."""
    if not k in diz:
        diz[k] = v
    else:
        diz[k] += v

def compute_avg_length(ss_list):
    """Prende in ingresso una lista di coppie (el. di ss, lunghezza).
Restituisce un dizionario el. di ss -> lunghezza media nella lista."""
    length_diz = {}
    count_diz = {}
    
    # estraggo lunghezze e conteggi
    for el,length in ss_list:
        sum_value_to_diz(length_diz, el, length)
        sum_value_to_diz(count_diz, el, 1)

    # normalizzo
    for el in length_diz:
        length_diz[el] /= count_diz[el]

    return length_diz

def compute_avg_num_segments(ss_list):
    """Prende in ingresso una lista di coppie (el. di ss, lunghezza).
Restituisce un dizionario el. di ss -> numero di occorrenze medie consecutive nella lista."""
    count_diz = {}
    non_cons_diz = {}
    curr_el = ""

    for el,length in ss_list:
        sum_value_to_diz(count_diz, el, 1)
        if not curr_el:
            curr_el = el
        elif curr_el != el:
            # aggiorno numero elementi
            sum_value_to_diz(non_cons_diz, curr_el, 1)
            curr_el = el

    # aggiorno ultimo elemento
    sum_value_to_diz(non_cons_diz, curr_el, 1)

    # normalizzo  
    for el in count_diz:
        count_diz[el] /= non_cons_diz[el]
    
    return count_diz

def print_freq_diz(diz):
    """Prende in ingresso un dizionario di frequenze e lo stampa."""
    print("\n".join(["%s -> %.3f" %(k,v) for k,v in diz.items()]))

filename = input("Inserire nome file: ")
ss_list = load_ss(filename)
avg_length = compute_avg_length(ss_list)
avg_num_seg = compute_avg_num_segments(ss_list)

print("Lunghezza media")
print_freq_diz(avg_length)
print("Numero medio di segmenti di ss")
print_freq_diz(avg_num_seg)

